#greentext

##About
greentext is a 4chan object library for navigating the 4chan API intuitively.

When using **greentext**, it goes without saying that you need to adhere to the [4chan API rules](https://github.com/4chan/4chan-API#api-rules).